<?php
require_once 'PHPUnit/Framework.php';

require_once dirname(__FILE__).'/../Query.php';
require_once '../Page.php';
require_once 'Test.php';
require_once 'Import.php';
require_once '../lib/simple_html_dom.php';

/**
 * Test class for Query.
 * Generated by PHPUnit on 2010-01-07 at 14:19:58.
 */
class QueryTest extends PHPUnit_Framework_TestCase {
    /**
     * @var Query
     */
    protected $object;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp() {
        $page = new Test();
        $this->object = $page->getQuery();
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown() {
    }

    /**
     * Implement testId().
     */
    public function testId() {
        $this->assertEquals($this->object->id('test')->text(), 'test');
    }

    /**
     * Implement testAttr().
     */
    public function testAttr() {
        $this->assertEquals($this->object->id('test')->attr('id'), 'test');
        $this->object->id('test')->attr('title', 'hoge');
        $this->assertEquals($this->object->id('test')->attr('title'), 'hoge');
    }

    /**
     * Implement testRemoveAttr().
     */
    public function testRemoveAttr() {
        $this->object->id('test')->attr('title', 'hoge');
        $this->assertEquals($this->object->id('test')->attr('title'), 'hoge');
        $this->object->removeAttr('title');
        $this->assertTrue($this->object->id('test')->attr('title')); //??
    }

    /**
     * Implement testAddClass().
     */
    public function testAddClass() {
        $this->object->id('test')->addClass('foo');
        $this->assertEquals($this->object->id('test')->attr('class'), 'foo');
    }

    /**
     * Implement testRemoveClass().
     */
    public function testRemoveClass() {
        $this->object->id('test')->addClass('foo bar');
        $this->object->id('test')->removeClass('foo');
        $this->assertEquals($this->object->id('test')->attr('class'), 'bar');
    }

    /**
     * Implement testToggleClass().
     */
    public function testToggleClass() {
        $this->object->id('test')->toggleClass('foo');
        $this->assertEquals($this->object->id('test')->attr('class'), 'foo');
        $this->object->id('test')->toggleClass('foo');
        $this->assertEquals($this->object->id('test')->attr('class'), false);
    }

    /**
     * Implement testHtml().
     */
    public function testHtml() {
        $this->assertEquals(trim($this->object->id('test2')->html()), '<p>test</p>');
        $this->object->id('test2')->html('<div>test</div>');
        $this->assertEquals(trim($this->object->id('test2')->html()), '<div>test</div>');
    }

    /**
     * Implement testVal().
     */
    public function testVal() {
        $this->object->id('test3')->val('hoge');
        $this->assertEquals($this->object->id('test3')->attr('value'), 'hoge');
    }

    /**
     * Implement testText().
     */
    public function testText() {
        $this->assertEquals($this->object->id('test')->text(), 'test');
        $this->object->id('test')->text('てすと');
        $this->assertEquals($this->object->id('test')->text(), 'てすと');
    }

    /**
     * Implement testClean().
     */
    public function testClean() {
        $this->object->id('test')->clean();
        $this->assertEquals($this->object->id('test')->text(), '');
    }

    /**
     * Implement testAppend().
     */
    public function testAppend() {
        $this->object->id('test')->append('<p>foo</p>');
        $this->assertEquals($this->object->id('test')->text(), 'test<p>foo</p>');
    }

    /**
     * Implement testAppendText().
     */
    public function testAppendText() {
        $this->object->id('test')->appendText('<p>foo</p>');
        $this->assertEquals($this->object->id('test')->text(), 'test&lt;p&gt;foo&lt;/p&gt;');
    }

    /**
     * Implement testGetDom().
     */
    public function testGetDom() {
        $dom = file_get_html('test.html');
        $this->assertEquals($dom->save(), $this->object->getDom()->save());
    }

    /**
     * Implement testLoop().
     */
    public function testLoop() {
        $arr = array();
        for($i = 0; $i < 2; $i++) {
            $c = new stdClass();
            $c->loop = $i;
            $arr[] = $c;
        }
        $this->object->id('looptest')->loop($arr);
        $this->assertEquals(trim($this->object->id('wrap')->html()), '<p title="loop">0</p><p title="loop">1</p>');
    }

    /**
     * Implement testImport().
     */
    public function testImport() {
        $this->object->id('import')->import(new Import());
        $this->assertEquals($this->object->id('import')->html(), '<p>import</p>');
    }

    /**
     * Implement testDummy().
     */
    public function testDummy() {
        $this->object->id('dummy')->dummy();
        $html = str_get_html($this->object->getDom()->save());
        $this->assertEquals(count($html->find('#dummy')), 0);
    }
}